pub enum OverwriteConfigurationRequest {
Set {
overwrite_format: OverwriteFormat,
responder: OverwriteConfigurationSetResponder,
},
#[non_exhaustive] _UnknownMethod {
ordinal: u64,
control_handle: OverwriteConfigurationControlHandle,
method_type: MethodType,
},
}Expand description
Provides control of the blobfs overwrite configuration to the product, which
controls how it reponds to fuchsia.fxfs.BlobCreator.NeedsOverwrite
during updates and what format all writes will use.
Variants
Set
Set the current configuration.
#[non_exhaustive]_UnknownMethod
An interaction was received which does not match any known method.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.

control_handle: OverwriteConfigurationControlHandle
method_type: MethodTypeImplementations
Sourceimpl OverwriteConfigurationRequest
impl OverwriteConfigurationRequest
pub fn into_set( self, ) -> Option<(OverwriteFormat, OverwriteConfigurationSetResponder)>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL