pub struct OverwriteConfigurationMarker;Trait Implementations
Sourceimpl Clone for OverwriteConfigurationMarker
impl Clone for OverwriteConfigurationMarker
Sourcefn clone(&self) -> OverwriteConfigurationMarker
fn clone(&self) -> OverwriteConfigurationMarker
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OverwriteConfigurationMarker
impl Debug for OverwriteConfigurationMarker
Sourceimpl DiscoverableProtocolMarker for OverwriteConfigurationMarker
impl DiscoverableProtocolMarker for OverwriteConfigurationMarker
Sourceconst PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
const PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
The name of the protocol (to be used for service lookup and discovery).
Sourceimpl Hash for OverwriteConfigurationMarker
impl Hash for OverwriteConfigurationMarker
Sourceimpl Ord for OverwriteConfigurationMarker
impl Ord for OverwriteConfigurationMarker
Sourcefn cmp(&self, other: &OverwriteConfigurationMarker) -> Ordering
fn cmp(&self, other: &OverwriteConfigurationMarker) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for OverwriteConfigurationMarker
impl PartialEq for OverwriteConfigurationMarker
Sourcefn eq(&self, other: &OverwriteConfigurationMarker) -> bool
fn eq(&self, other: &OverwriteConfigurationMarker) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for OverwriteConfigurationMarker
impl PartialOrd for OverwriteConfigurationMarker
Sourceimpl ProtocolMarker for OverwriteConfigurationMarker
impl ProtocolMarker for OverwriteConfigurationMarker
Sourceconst DEBUG_NAME: &'static str = "fuchsia.storage.blobfs.OverwriteConfiguration"
const DEBUG_NAME: &'static str = "fuchsia.storage.blobfs.OverwriteConfiguration"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = OverwriteConfigurationProxy
type Proxy = OverwriteConfigurationProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = OverwriteConfigurationRequestStream
type RequestStream = OverwriteConfigurationRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = OverwriteConfigurationSynchronousProxy
type SynchronousProxy = OverwriteConfigurationSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl Copy for OverwriteConfigurationMarker
impl Eq for OverwriteConfigurationMarker
impl StructuralPartialEq for OverwriteConfigurationMarker